Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(616)

Unified Diff: runtime/vm/constants_dbc.h

Issue 2258613002: DBC: Instructions for bailouts from http tests. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/intermediate_language_dbc.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/constants_dbc.h
diff --git a/runtime/vm/constants_dbc.h b/runtime/vm/constants_dbc.h
index 3f950dffdceb0617bfc4e327f658a2c8fd6b81f0..5cf7edc8304747493151a2aafa06a910b8a544f8 100644
--- a/runtime/vm/constants_dbc.h
+++ b/runtime/vm/constants_dbc.h
@@ -313,21 +313,30 @@ namespace dart {
// Store FP[rC] into array FP[rA] at index FP[rB]. No typechecking is done.
// FP[rA] is assumed to be a RawArray, FP[rB] to be a smi.
//
// - StoreFloat64Indexed rA, rB, rC
//
-// Store the unboxed double in FP[rC] into the typed data array at FP[rA]
-// at index FP[rB].
+// Store the unboxed double or tagged Smi in FP[rC] into the typed data array
+// at FP[rA] at index FP[rB].
+//
+// - StoreIndexedExternalUint8 rA, rB, rC
+//
+// Similar to StoreIndexedUint8 but FP[rA] is an external typed data aray.
//
// - LoadIndexed rA, rB, rC
//
// Loads from array FP[rB] at index FP[rC] into FP[rA]. No typechecking is
// done. FP[rB] is assumed to be a RawArray, and to contain a Smi at FP[rC].
//
// - Load{Float64, OneByteString, TwoByteString}Indexed rA, rB, rC
//
// Loads from typed data array FP[rB] at index FP[rC] into an unboxed double,
// or tagged Smi in FP[rA] as indicated by the type in the name.
//
+// - LoadIndexedExternal{Int8, Uint8} rA, rB, rC
+//
+// Loads from the external typed data array FP[rB] at index FP[rC] into
+// FP[rA]. No typechecking is done.
+//
// - StoreField rA, B, rC
//
// Store value FP[rC] into object FP[rA] at offset (in words) B.
@@ -340,6 +349,10 @@ namespace dart {
//
// Load value at offset (in words) C from object FP[rB] into FP[rA].
//
+// - LoadUntagged rA, rB, C
+//
+// Like LoadField, but assumes that FP[rB] is untagged.
+//
// - LoadFieldTOS D
//
// Push value at offset (in words) D from object SP[0].
@@ -651,14 +664,21 @@ namespace dart {
V(AllocateT, 0, ___, ___, ___) \
V(StoreIndexedTOS, 0, ___, ___, ___) \
V(StoreIndexed, A_B_C, reg, reg, reg) \
- V(StoreFloat64Indexed, A_B_C, reg, reg, reg) \
+ V(StoreIndexedUint8, A_B_C, reg, reg, reg) \
+ V(StoreIndexedExternalUint8, A_B_C, reg, reg, reg) \
+ V(StoreIndexedFloat64, A_B_C, reg, reg, reg) \
V(LoadIndexed, A_B_C, reg, reg, reg) \
- V(LoadFloat64Indexed, A_B_C, reg, reg, reg) \
- V(LoadOneByteStringIndexed, A_B_C, reg, reg, reg) \
- V(LoadTwoByteStringIndexed, A_B_C, reg, reg, reg) \
+ V(LoadIndexedUint8, A_B_C, reg, reg, reg) \
+ V(LoadIndexedInt8, A_B_C, reg, reg, reg) \
+ V(LoadIndexedExternalUint8, A_B_C, reg, reg, reg) \
+ V(LoadIndexedExternalInt8, A_B_C, reg, reg, reg) \
+ V(LoadIndexedFloat64, A_B_C, reg, reg, reg) \
+ V(LoadIndexedOneByteString, A_B_C, reg, reg, reg) \
+ V(LoadIndexedTwoByteString, A_B_C, reg, reg, reg) \
V(StoreField, A_B_C, reg, num, reg) \
V(StoreFieldTOS, D, num, ___, ___) \
V(LoadField, A_B_C, reg, reg, num) \
+ V(LoadUntagged, A_B_C, reg, reg, num) \
V(LoadFieldTOS, D, num, ___, ___) \
V(BooleanNegateTOS, 0, ___, ___, ___) \
V(BooleanNegate, A_D, reg, reg, ___) \
@@ -313,21 +313,30 @@ namespace dart {
// FP[rA] is assumed to be a RawArray, FP[rB] to be a smi.
//
-// - StoreFloat64Indexed rA, rB, rC
+// - StoreIndexed{Float64, Uint8} rA, rB, rC
//
@@ -313,21 +313,30 @@ namespace dart {
// done. FP[rB] is assumed to be a RawArray, and to contain a Smi at FP[rC].
//
-// - Load{Float64, OneByteString, TwoByteString}Indexed rA, rB, rC
+// - LoadIndexed{Float64, OneByteString, TwoByteString, Uint8, Int8} rA, rB, rC
//
// Loads from typed data array FP[rB] at index FP[rC] into an unboxed double,
« no previous file with comments | « no previous file | runtime/vm/intermediate_language_dbc.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698